==> nextcloud-18.0.9.tgz: nextcloud/apps/workflowengine/l10n/sl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Podan operator ni veljaven.",
    "The given regular expression is invalid" : "Podan logični izraz ni veljaven.",
    "The given file size is invalid" : "Podana velikost datoteke ni veljavna.",
    "The given tag id is invalid" : "Podan ID oznake ni veljaven.",
    "The given IP range is invalid" : "Podan obseg IP ni veljaven.",
    "The given IP range is not valid for IPv4" : "Podan obseg IP ni veljaven za IPv4.",
    "The given IP range is not valid for IPv6" : "Podan obseg IP ni veljaven za IPv6.",
    "The given time span is invalid" : "Podan časovni obseg ni veljaven.",
    "The given start time is invalid" : "Podan čas začetka ni veljaven.",
    "The given end time is invalid" : "Podan čas zaključka ni veljaven.",
    "The given group does not exist" : "Podana skupina ne obstaja.",
    "File" : "Datoteka",
    "File created" : "datoteka ustvarjena",
    "File updated" : "datoteka posodobljena",
    "File renamed" : "datoteka preimenovana",
    "File deleted" : "datoteka izbrisana",
    "File accessed" : "datoteka dostopana",
    "File copied" : "datoteka kopirana",
    "Tag assigned" : "datoteka dodeljena",
    "Someone" : "Kdorkoli",
    "%s created %s" : "%s ustvari %s",
    "%s modified %s" : "%s spremeni %s",
    "%s deleted %s" : "%s izbriše %s",
    "%s accessed %s" : "%s dostopi do %s",
    "%s renamed %s" : "%s preimenuje %s",
    "%s copied %s" : "%s kopira %s",
    "%s assigned %s to %s" : "%s dodelo %s za %s",
    "Operation #%s does not exist" : "Opravilo #%s ne obstaja.",
    "Entity %s does not exist" : "Predmet %s ne obstaja.",
    "Entity %s is invalid" : "Predmet %s ni veljaven.",
    "No events are chosen." : "Ni izbranega nobenega dogodka.",
    "Entity %s has no event %s" : "Predmetu %s ni določen noben dogodek %s",
    "Operation %s does not exist" : "Opravilo %s ne obstaja.",
    "Operation %s is invalid" : "Opravilo %s ni veljavno.",
    "At least one check needs to be provided" : "Izbrano mora biti vsaj eno pravilo preverjanja",
    "Invalid check provided" : "Podano je neveljavno pravilo preverjanja",
    "Check %s does not exist" : "Pravilo preverjanja %s ne obstaja.",
    "Check %s is invalid" : "Pravilo preverjanja %s ni veljavno.",
    "Check %s is not allowed with this entity" : "Pravilo preverjanja %s s tem predmetom ni veljavno",
    "Check #%s does not exist" : "Preverba #%s ne obstaja.",
    "Check %s is invalid or does not exist" : "Preverba %s ne obstaja.",
    "Flow" : "Koračnik (Flow)",
    "Nextcloud workflow engine" : "Program za koračno avtomatizacijo delovnih nalog",
    "Select a filter" : "Izbor filtra",
    "Select a comparator" : "Izbor primerjalnika",
    "Select a file type" : "Izbor vrste datoteke",
    "e.g. httpd/unix-directory" : "npr. httpd/unix-directory",
    "Folder" : "Mapa",
    "Images" : "Slike",
    "Office documents" : "Pisarniški dokumenti",
    "PDF documents" : "Dokumenti PDF",
    "Custom mimetype" : "Vrsta Mime po meri",
    "Select a tag" : "Izbor oznake",
    "No results" : "Ni zadetkov",
    "%s (invisible)" : "%s (nevidno)",
    "%s (restricted)" : "%s (omejeno)",
    "Please enter a valid time span" : "Vpisati je treba veljaven časovni obseg",
    "Select a request URL" : "Izberite naslov URL zahteve",
    "Predefined URLs" : "Določeni naslovi URL",
    "Files WebDAV" : "Datoteke WebDAV",
    "Others" : "Ostali",
    "Custom URL" : "Naslov URL po meri",
    "Select a user agent" : "Izbor uporabniškega odjemalca",
    "Android client" : "Odjemalec za Android",
    "iOS client" : "Odjemalec za iOS",
    "Desktop client" : "Odjemalec za namizne računalnike",
    "Thunderbird & Outlook addons" : "Razširitve za Thunderbird in Outlook",
    "Custom user agent" : "Uporabniški odjemalec po meri",
    "At least one event must be selected" : "Izbran mora biti vsaj en dogodek",
    "Add new flow" : "Dodaj koračnik",
    "When" : "Ko je",
    "and" : "in",
    "Cancel" : "Prekliči",
    "Delete" : "Izbriši",
    "The configuration is invalid" : "Nastavitev ni veljavna",
    "Active" : "Dejavno",
    "Save" : "Shrani",
    "Available flows" : "Razpoložljii koračniki",
    "For details on how to write your own flow, check out the development documentation." : "Za podrobnosti, kako sestaviti koračnike po meri, preverite razvijalsko dokumentacijo.",
    "More flows" : "Več koračnikov",
    "Browse the app store" : "Prebrskaj po trgovini programov",
    "Show less" : "Pokaži manj",
    "Show more" : "Pokaži več",
    "Configured flows" : "Nastavljeni koračniki",
    "Your flows" : "Koračniki po meri",
    "matches" : "se sklada z",
    "does not match" : "se ne sklada z",
    "is" : "je",
    "is not" : "ni",
    "File name" : "Ime datoteke",
    "File MIME type" : "Vrsta MIME datoteke",
    "File size (upload)" : "Velikost datoteke (pošiljanje)",
    "less" : "je manjša",
    "less or equals" : "je manjša ali enaka",
    "greater or equals" : "je večja ali enaka",
    "greater" : "je večja",
    "Request remote address" : "Oddaljeni naslov",
    "matches IPv4" : "se sklada z IPv4",
    "does not match IPv4" : "ni skladen z IPv4",
    "matches IPv6" : "se sklada z IPv6",
    "does not match IPv6" : "ni skladen z IPv6",
    "File system tag" : "Sistemska oznaka datoteke",
    "is tagged with" : "je",
    "is not tagged with" : "ni",
    "Request URL" : "Naslov URL za dostop",
    "Request time" : "Čas dostopa",
    "between" : "je dovoljen med",
    "not between" : "ni dovoljen med",
    "Request user agent" : "Uporabniški odjemalec",
    "User group membership" : "Članstvo v uporabniških skupinah",
    "is member of" : "je v skupini",
    "is not member of" : "ni v skupini",
    "Example: {placeholder}" : "Primer: {placeholder}",
    "Select tag…" : "Izbor oznake ...",
    "Start" : "Začetek",
    "End" : "Konec",
    "Select timezone…" : "Časovni pas ...",
    "Sync clients" : "Odjemalci za usklajevanje",
    "Short rule description" : "Kratek opis pravila",
    "Add rule" : "Dodaj pravilo",
    "Reset" : "Razveljavi",
    "Saving…" : "Poteka shranjevanje ...",
    "Group list is empty" : "Skupinski seznam je prazen",
    "Unable to retrieve the group list" : "Skupinskega seznama ni mogoče pridobiti.",
    "Saved" : "Shranjeno",
    "Saving failed:" : "Shranjevanje je spodletelo:",
    "Add rule group" : "Dodaj skupino pravil",
    "Tag management" : "Upravljanje oznak",
    "Files workflow engine" : "Program za koračno upravljanje z datotekami",
    "Open documentation" : "Odpri dokumentacijo",
    "Loading…" : "Poteka nalaganje ..."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.10.tgz: nextcloud/apps/workflowengine/l10n/sl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Podan operator ni veljaven.",
    "The given regular expression is invalid" : "Podan logični izraz ni veljaven.",
    "The given file size is invalid" : "Podana velikost datoteke ni veljavna.",
    "The given tag id is invalid" : "Podan ID oznake ni veljaven.",
    "The given IP range is invalid" : "Podan obseg IP ni veljaven.",
    "The given IP range is not valid for IPv4" : "Podan obseg IP ni veljaven za IPv4.",
    "The given IP range is not valid for IPv6" : "Podan obseg IP ni veljaven za IPv6.",
    "The given time span is invalid" : "Podan časovni obseg ni veljaven.",
    "The given start time is invalid" : "Podan čas začetka ni veljaven.",
    "The given end time is invalid" : "Podan čas zaključka ni veljaven.",
    "The given group does not exist" : "Podana skupina ne obstaja.",
    "File" : "Datoteka",
    "File created" : "datoteka ustvarjena",
    "File updated" : "datoteka posodobljena",
    "File renamed" : "datoteka preimenovana",
    "File deleted" : "datoteka izbrisana",
    "File accessed" : "datoteka dostopana",
    "File copied" : "datoteka kopirana",
    "Tag assigned" : "datoteka dodeljena",
    "Someone" : "Nekdo",
    "%s created %s" : "%s ustvari %s",
    "%s modified %s" : "%s spremeni %s",
    "%s deleted %s" : "%s izbriše %s",
    "%s accessed %s" : "%s dostopi do %s",
    "%s renamed %s" : "%s preimenuje %s",
    "%s copied %s" : "%s kopira %s",
    "%s assigned %s to %s" : "%s dodeli %s za %s",
    "Operation #%s does not exist" : "Opravilo #%s ne obstaja.",
    "Entity %s does not exist" : "Predmet %s ne obstaja.",
    "Entity %s is invalid" : "Predmet %s ni veljaven.",
    "No events are chosen." : "Ni izbranega nobenega dogodka.",
    "Entity %s has no event %s" : "Predmetu %s ni določen noben dogodek %s",
    "Operation %s does not exist" : "Opravilo %s ne obstaja.",
    "Operation %s is invalid" : "Opravilo %s ni veljavno.",
    "At least one check needs to be provided" : "Izbrano mora biti vsaj eno pravilo preverjanja",
    "The provided operation data is too long" : "Podani podatki opravila so predolgi",
    "Invalid check provided" : "Podano je neveljavno pravilo preverjanja",
    "Check %s does not exist" : "Pravilo preverjanja %s ne obstaja.",
    "Check %s is invalid" : "Pravilo preverjanja %s ni veljavno.",
    "Check %s is not allowed with this entity" : "Pravilo preverjanja %s s tem predmetom ni veljavno",
    "The provided check value is too long" : "Podani vrednost preverjanja je predolga",
    "Check #%s does not exist" : "Preverba #%s ne obstaja.",
    "Check %s is invalid or does not exist" : "Preverba %s ne obstaja.",
    "Flow" : "Koračnik (Flow)",
    "Nextcloud workflow engine" : "Program za koračno avtomatizacijo delovnih nalog",
    "Select a filter" : "Izbor filtra",
    "Select a comparator" : "Izbor primerjalnika",
    "Select a file type" : "Izbor vrste datoteke",
    "e.g. httpd/unix-directory" : "npr. httpd/unix-directory",
    "Folder" : "Mapa",
    "Images" : "Slike",
    "Office documents" : "Pisarniški dokumenti",
    "PDF documents" : "Dokumenti PDF",
    "Custom mimetype" : "Vrsta Mime po meri",
    "Select a tag" : "Izbor oznake",
    "No results" : "Ni zadetkov",
    "%s (invisible)" : "%s (nevidno)",
    "%s (restricted)" : "%s (omejeno)",
    "Please enter a valid time span" : "Vpisati je treba veljaven časovni obseg",
    "Select a request URL" : "Izberite naslov URL zahteve",
    "Predefined URLs" : "Določeni naslovi URL",
    "Files WebDAV" : "Datoteke WebDAV",
    "Others" : "Ostali",
    "Custom URL" : "Naslov URL po meri",
    "Select a user agent" : "Izbor uporabniškega odjemalca",
    "Android client" : "Odjemalec za Android",
    "iOS client" : "Odjemalec za iOS",
    "Desktop client" : "Odjemalec za namizne računalnike",
    "Thunderbird & Outlook addons" : "Razširitve za Thunderbird in Outlook",
    "Custom user agent" : "Uporabniški odjemalec po meri",
    "At least one event must be selected" : "Izbran mora biti vsaj en dogodek",
    "Add new flow" : "Dodaj koračnik",
    "When" : "Ko je",
    "and" : "in",
    "Cancel" : "Prekliči",
    "Delete" : "Izbriši",
    "The configuration is invalid" : "Nastavitev ni veljavna",
    "Active" : "Dejavno",
    "Save" : "Shrani",
    "Available flows" : "Razpoložljivi koračniki",
    "For details on how to write your own flow, check out the development documentation." : "Za podrobnosti, kako sestaviti koračnike po meri, preverite razvijalsko dokumentacijo.",
    "More flows" : "Več koračnikov",
    "Browse the app store" : "Prebrskaj po trgovini programov",
    "Show less" : "Pokaži manj",
    "Show more" : "Pokaži več",
    "Configured flows" : "Nastavljeni koračniki",
    "Your flows" : "Koračniki po meri",
    "matches" : "se sklada z",
    "does not match" : "se ne sklada z",
    "is" : "je",
    "is not" : "ni",
    "File name" : "Ime datoteke",
    "File MIME type" : "Vrsta MIME datoteke",
    "File size (upload)" : "Velikost datoteke (↑)",
    "less" : "je manjša",
    "less or equals" : "je manjša ali enaka",
    "greater or equals" : "je večja ali enaka",
    "greater" : "je večja",
    "Request remote address" : "Oddaljeni naslov",
    "matches IPv4" : "se sklada z IPv4",
    "does not match IPv4" : "ni skladen z IPv4",
    "matches IPv6" : "se sklada z IPv6",
    "does not match IPv6" : "ni skladen z IPv6",
    "File system tag" : "Sistemska oznaka",
    "is tagged with" : "je",
    "is not tagged with" : "ni",
    "Request URL" : "Naslov URL za dostop",
    "Request time" : "Čas dostopa",
    "between" : "je dovoljen med",
    "not between" : "ni dovoljen med",
    "Request user agent" : "Uporabniški odjemalec",
    "User group membership" : "Članstvo v uporabniških skupinah",
    "is member of" : "je v skupini",
    "is not member of" : "ni v skupini"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
